import { AnyAction } from '@reduxjs/toolkit';
import * as toolkitRaw from '@reduxjs/toolkit';
import type { ToolkitStore } from '@reduxjs/toolkit/dist/configureStore';
import drawerReducer, { openDrawer, closeDrawer } from './drawer.slice';
import type { DrawerState } from './drawer.types';

const INITIAL_STATE: DrawerState = {
  open: false,
  pathName: 'none',
};

type SliceReducerType = ToolkitStore<
  {
    drawer: DrawerState;
  },
  AnyAction
>;

const createStoreInstanceUsingSliceReducer = (): SliceReducerType =>
  toolkitRaw.configureStore({
    reducer: {
      drawer: drawerReducer,
    },
  });

describe('drawer reducer', () => {
  let store = {} as SliceReducerType;

  beforeEach(() => {
    store = createStoreInstanceUsingSliceReducer();
  });

  it('should match initial state', () => {
    const action = { type: 'unknown' };

    expect(drawerReducer(undefined, action)).toEqual(INITIAL_STATE);
  });

  it('should update the store when you click a project info button on the nav bar', async () => {
    const { type } = await store.dispatch(openDrawer('project-info'));
    const { open, pathName } = store.getState().drawer;

    expect(type).toBe('drawer/openDrawer');
    expect(open).toBe(true);
    expect(pathName).toEqual('project-info');
  });

  it('should update the store when you click the close button on the drawer', async () => {
    const { type } = await store.dispatch(closeDrawer('project-info'));
    const { open, pathName } = store.getState().drawer;

    expect(type).toBe('drawer/closeDrawer');
    expect(open).toBe(false);
    expect(pathName).toEqual('project-info');
  });

  it.skip('should update the store when you type in the search', async () => {
    // TODO
  });
});
